package com.hmonitor.application;

import java.util.ArrayList;
import java.util.Date;

import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.IBinder;
import android.os.Vibrator;
import android.telephony.SmsManager;
import at.abraxas.amarino.Amarino;
import at.abraxas.amarino.AmarinoIntent;

public class HeartRateService extends Service{
    private ArrayList<HeartRate> heartRates;
    private String key;
    private String phone;
    private String firstName;
    private String name;
    private long lastAlert;
    
    private ArduinoReceiver arduinoReceiver = new ArduinoReceiver();
    
	// change this to your Bluetooth device address 
	private static final String DEVICE_ADDRESS =  "00:06:66:43:46:80"; //"00:06:66:03:73:7B";

	@Override
	public void onCreate(){
		heartRates = ((HMonitorApplication) getApplication()).getHeartRates();
		key = ((HMonitorApplication) getApplication()).getKey();
		phone = ((HMonitorApplication) getApplication()).getPhone();
		firstName = ((HMonitorApplication) getApplication()).getFirstName();
		name = ((HMonitorApplication) getApplication()).getName();
		lastAlert = 0;
	}

	@Override
	public IBinder onBind(Intent arg0) {
		// TODO Auto-generated method stub
		return null;
	}
	
	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
	      
		//new Thread(new HeartRateThread(heartRates, key)).start();
		
		
		// in order to receive broadcasted intents we need to register our receiver
		registerReceiver(arduinoReceiver, new IntentFilter(AmarinoIntent.ACTION_RECEIVED));
		
		// this is how you tell Amarino to connect to a specific BT device from within your own code
		Amarino.connect(this, DEVICE_ADDRESS);

	    // We want this service to continue running until it is explicitly
	    // stopped, so return sticky.
	    return START_STICKY;
	}	

	/**
	 * ArduinoReceiver is responsible for catching broadcasted Amarino
	 * events.
	 * 
	 * It extracts data from the intent and updates the graph accordingly.
	 */
	public class ArduinoReceiver extends BroadcastReceiver {

		@Override
		public void onReceive(Context context, Intent intent) {
			String data = null;
			
			// the device address from which the data was sent, we don't need it here but to demonstrate how you retrieve it
			final String address = intent.getStringExtra(AmarinoIntent.EXTRA_DEVICE_ADDRESS);
			
			// the type of data which is added to the intent
			final int dataType = intent.getIntExtra(AmarinoIntent.EXTRA_DATA_TYPE, -1);
			
			// we only expect String data though, but it is better to check if really string was sent
			// later Amarino will support differnt data types, so far data comes always as string and
			// you have to parse the data to the type you have sent from Arduino, like it is shown below
			if (dataType == AmarinoIntent.STRING_EXTRA){
				data = intent.getStringExtra(AmarinoIntent.EXTRA_DATA);
				
				if (data != null){
					try {
						Date date = new Date();
						long currentTimeStamp = date.getTime()/1000;
						HeartRate heartRate = new HeartRate(currentTimeStamp, data);
						heartRates.add(heartRate);
						
						System.out.println(heartRate.getHeartRate());

						if(((Double.parseDouble(data) < 50) || (Double.parseDouble(data) > 80)) && ((currentTimeStamp-lastAlert)>60)) sendAlert(heartRate);
					} 
					catch (NumberFormatException e) { /* oh data was not an integer */ }
				}
			}
		}

	}
	
	public void sendAlert(HeartRate heartRate) {
		Localisation lastLocalisation = ((HMonitorApplication) getApplication()).getLastLocalisation();
		
		Vibrator vibrator = (Vibrator) getSystemService(Context.VIBRATOR_SERVICE);
		vibrator.vibrate(2000);
		
		if(phone.length()>= 4){
			SmsManager.getDefault().sendTextMessage(phone, null, "WARNING : BAD DATA RECEIVED FROM " + firstName + " " + name + ": " + heartRate + "\n Localisation: " + lastLocalisation, null, null);
		}

		Date date = new Date();
		lastAlert = date.getTime()/1000;

	}
}
